2.x
===

.. include:: ../full_changelog_explanation.rst
.. include:: ../summary_explanation.rst

.. toctree::
   :maxdepth: 2

   2.17/index
   2.16/index
   2.15/index
   2.14/index
   2.13/index
   2.12/index
   2.11/index
   2.10/index
   2.9/index
   2.8/index
   2.7/index
   2.6/index
   2.5/index
   2.4/index
   2.3/index
   2.2/index
   2.1/index
   2.0/index
